maze-serval 0.6.8

Serval helps you prepare data for Maze and Trapper
docs.rs failed to build maze-serval-0.6.8
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: maze-serval-0.6.5

Serval

A command line tool for camera trap data wrangling in the Maze team.

Build

cargo build

Installation

cargo install maze-serval

License

GPL-3.0